@@ -114,7 +114,7 @@ class WebPlatformTests(object):
                     os.makedirs(dest_dir)
                 shutil.copy2(source_path, dest_path)
 
-        for source, destination in [("gecko_runner.html", ""),
+        for source, destination in [("testharness_runner.html", ""),
                                     ("testharnessreport.js", "resources/")]:
             source_path = os.path.join(base_path, source)
             dest_path = os.path.join(dest, destination, os.path.split(source)[1])
